.. image:: https://img.shields.io/lgtm/grade/python/g/StagPython/StagPy.svg?logo=lgtm&logoWidth=18
   :target: https://lgtm.com/projects/g/StagPython/StagPy
   :alt: Language grade: Python

.. image:: https://travis-ci.org/StagPython/StagPy.svg?branch=master
   :target: https://travis-ci.org/StagPython/StagPy
   :alt: Travis CI

.. image:: https://readthedocs.org/projects/stagpy/badge/?version=latest
   :target: https://stagpy.readthedocs.org/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://badge.fury.io/py/stagpy.svg
   :target: https://badge.fury.io/py/stagpy
   :alt: PyPI Version

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.5512348.svg
   :target: https://doi.org/10.5281/zenodo.5512348
   :alt: DIO on zenodo

StagPy
======

StagPy is a command line tool to process the output files of your StagYY
simulations and produce high-quality figures.

This command line tool is built around a generic interface that allows you to
access StagYY output data directly in a Python script.

You can install StagPy with ``pip`` from the `Python Package Index`__.

This project is registered under https://doi.org/10.5281/zenodo.5512348.
Individual DOI are also available to cite a specific version.  Cite the project
as:

    Adrien Morison, Martina Ulvrova, Stephane Labrosse, & contributors. (2021).
    StagPython/StagPy. Zenodo. https://doi.org/10.5281/zenodo.5512348

or a specific version with the relevant DOI (e.g. for v0.15.0):

    Adrien Morison, Martina Ulvrova, Stephane Labrosse, & contributors. (2021).
    StagPython/StagPy (v0.15.0). Zenodo. https://doi.org/10.5281/zenodo.5512349

See `the complete documentation`__ for more information on the installation and
explanations on how to use StagPy.

.. __: https://pypi.org/project/stagpy/
.. __: https://stagpy.readthedocs.org
